pub enum RecvError {
Disconnected,
}Expand description
An error returned from the recv and try_recv methods.
This error indicates that the channel is empty and disconnected, meaning all senders have been dropped and no more messages will be sent.
Variants
Disconnected
The channel is empty and disconnected.