pub struct SendError<T>(pub T);Expand description
An error returned from the send method.
The error contains the value that could not be sent. This occurs when the channel is disconnected, meaning all receivers have been dropped.
Tuple Fields
0: TTrait Implementations
Sourceimpl<T: Send> Error for SendError<T>
impl<T: Send> Error for SendError<T>
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
impl<T: Copy> Copy for SendError<T>
impl<T: Eq> Eq for SendError<T>
impl<T> StructuralPartialEq for SendError<T>